@@ -145,8 +145,8 @@ struct msgs {
  * macros for message and sequence manipulation
  */
 #define does_exist(mp,msgnum)     ((mp)->msgstats[msgnum] & EXISTS)
-#define set_exists(mp,msgnum)     ((mp)->msgstats[msgnum] &= ~EXISTS)
-#define unset_exists(mp,msgnum)   ((mp)->msgstats[msgnum] |= EXISTS)
+#define unset_exists(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~EXISTS)
+#define set_exists(mp,msgnum)     ((mp)->msgstats[msgnum] |= EXISTS)
 
 #define is_selected(mp,msgnum)    ((mp)->msgstats[msgnum] & SELECTED)
 #define unset_selected(mp,msgnum) ((mp)->msgstats[msgnum] &= ~SELECTED)
