@@ -240,21 +240,39 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	    cp = name;
 	    i = NAMESZ - 1;
 	    for (;;) {
+#ifdef LINUX_STDIO
+		bp = sp = (unsigned char *) iob->_IO_read_ptr - 1;
+		j = (cnt = ((long) iob->_IO_read_end -
+			(long) iob->_IO_read_ptr)  + 1) < i ? cnt : i;
+#else
 		bp = sp = (unsigned char *) iob->_ptr - 1;
 		j = (cnt = iob->_cnt+1) < i ? cnt : i;
+#endif
 		while ((c = *bp++) != ':' && c != '\n' && --j >= 0)
 		    *cp++ = c;
 
 		j = bp - sp;
 		if ((cnt -= j) <= 0) {
+#ifdef LINUX_STDIO
+		    iob->_IO_read_ptr = iob->_IO_read_end;
+		    if (__underflow(iob) == EOF) {
+#else
 		    if (_filbuf(iob) == EOF) {
+#endif
 			*cp = *buf = 0;
 			advise (NULL, "eof encountered in field \"%s\"", name);
 			return FMTERR;
 		    }
+#ifdef LINUX_STDIO
+		iob->_IO_read_ptr++; /* NOT automatic in __underflow()! */
+#endif
 		} else {
+#ifdef LINUX_STDIO
+		    iob->_IO_read_ptr = bp + 1;
+#else
 		    iob->_ptr = bp + 1;
 		    iob->_cnt = cnt - 1;
+#endif
 		}
 		if (c == ':')
 		    break;
@@ -292,16 +310,27 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	     */
 	    cp = buf; i = bufsz-1;
 	    for (;;) {
+#ifdef LINUX_STDIO
+		cnt = (long) iob->_IO_read_end - (long) iob->_IO_read_ptr;
+		bp = (unsigned char *) --iob->_IO_read_ptr;
+#else
 		cnt = iob->_cnt++; bp = (unsigned char *) --iob->_ptr;
+#endif
 		c = cnt < i ? cnt : i;
 		while ((ep = locc( c, bp, '\n' ))) {
 		    /*
 		     * if we hit the end of this field, return.
 		     */
 		    if ((j = *++ep) != ' ' && j != '\t') {
+#ifdef LINUX_STDIO
+			j = ep - (unsigned char *) iob->_IO_read_ptr;
+			memcpy( cp, iob->_IO_read_ptr, j);
+			iob->_IO_read_ptr = ep;
+#else
 			j = ep - (unsigned char *) iob->_ptr;
 			memcpy( cp, iob->_ptr, j);
 			iob->_ptr = ep; iob->_cnt -= j;
+#endif
 			cp += j;
 			state = FLD;
 			goto finish;
@@ -311,12 +340,21 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		/*
 		 * end of input or dest buffer - copy what we've found.
 		 */
+#ifdef LINUX_STDIO
+		c += bp - (unsigned char *) iob->_IO_read_ptr;
+		memcpy( cp, iob->_IO_read_ptr, c);
+#else
 		c += bp - (unsigned char *) iob->_ptr;
 		memcpy( cp, iob->_ptr, c);
+#endif
 		i -= c; cp += c;
 		if (i <= 0) {
 		    /* the dest buffer is full */
+#ifdef LINUX_STDIO
+		    iob->_IO_read_ptr += c;
+#else
 		    iob->_cnt -= c; iob->_ptr += c;
+#endif
 		    state = FLDPLUS;
 		    break;
 		}
@@ -327,11 +365,24 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		 * this is the end of the field.  Otherwise loop.
 		 */
 		--i;
+#ifdef LINUX_STDIO
+		*cp++ = j = *(iob->_IO_read_ptr + c);
+		iob->_IO_read_ptr = iob->_IO_read_end;
+		c = __underflow(iob);
+		iob->_IO_read_ptr++;    /* NOT automatic! */
+#else
 		*cp++ = j = *(iob->_ptr + c);
 		c = _filbuf(iob);
+#endif
 		if ((j == '\0' || j == '\n') && c != ' ' && c != '\t') {
-		    if (c != EOF)
-			--iob->_ptr, ++iob->_cnt;
+		    if (c != EOF) {
+#ifdef LINUX_STDIO
+			--iob->_IO_read_ptr;
+#else
+			--iob->_ptr;
+			++iob->_cnt;
+#endif
+		    }
 		    state = FLD;
 		    break;
 		}
@@ -347,7 +398,12 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	     * the output buffer and we don't add an eos.
 	     */
 	    i = (bufsz < 0) ? -bufsz : bufsz-1;
+#ifdef LINUX_STDIO
+	    bp = (unsigned char *) --iob->_IO_read_ptr;
+	    cnt = (long) iob->_IO_read_end - (long) iob->_IO_read_ptr;
+#else
 	    bp = (unsigned char *) --iob->_ptr; cnt = ++iob->_cnt;
+#endif
 	    c = (cnt < i ? cnt : i);
 	    if (msg_style != MS_DEFAULT && c > 1) {
 		/*
@@ -404,8 +460,12 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		}
 	    }
 	    memcpy( buf, bp, c );
+#ifdef LINUX_STDIO
+	    iob->_IO_read_ptr += c;
+#else
 	    iob->_cnt -= c;
 	    iob->_ptr += c;
+#endif
 	    if (bufsz < 0) {
 		msg_count = c;
 		return (state);
