@@ -15,9 +15,14 @@ showfile (char **arg, char *file)
     int isdraft, vecp;
     char *vec[MAXARGS];
 
-    m_update();
+    m_update();		/* update the context file */
     fflush(stdout);
 
+    /*
+     * If you have your lproc listed as "mhl",
+     * then really invoked the mhlproc instead
+     * (which is usually mhl anyway).
+     */
     if (!strcmp (r1bindex (lproc, '/'), "mhl"))
 	lproc = mhlproc;
 
