@@ -155,7 +155,6 @@ extern	int	   called_bbc;
 static	int bbp;
 #endif	UCL
 
-/* ARGSUSED */
 
 main (int argc, char **argv)
 {
@@ -390,11 +389,10 @@ topics () {
 }
 
 
-printv (key, value)
-register char   *key,
-	        *value;
+void
+printv (char *key, char *value)
 {
-    char    buffer[BUFSIZ];
+    char buffer[BUFSIZ];
 
     if (key)
 	sprintf (buffer, "%s: ", key);
@@ -407,11 +405,10 @@ register char   *key,
 }
 
 
-int     action (local, domain)
-register char   *local,
-		*domain;
+int
+action (char *local, char *domain)
 {
-    char    buffer[BUFSIZ];
+    char buffer[BUFSIZ];
 
     sprintf (buffer, "%s@%s", local, domain);
     printv (changed++ ? NULL : "Dist", buffer);
@@ -419,8 +416,8 @@ register char   *local,
 }
 
 
-printb (flags)
-unsigned int flags;
+void
+printb (unsigned int flags)
 {
     char buffer[BUFSIZ];
 
@@ -428,12 +425,15 @@ unsigned int flags;
 }
 
 
-check () {
 #define	grammar(a,b,c)	(a == 1 ? b : c)
 #define	plural(d)	grammar(d, "", "s")
 
-    int     diff;
-    register struct bboard  *bb;
+void
+check (void)
+{
+
+    int diff;
+    register struct bboard *bb;
 
     for (bb = bbl; bb; bb = bb->bb_link) {
 	diff = bb->bb_maxima - bb->bb_count;
@@ -462,9 +462,8 @@ check () {
 }
 
 
-process (vecp, vec)
-int	vecp;
-char   *vec[];
+void
+process (int vecp, char *vec[])
 {
     int diff;
 #ifdef	SIGTSTP
@@ -508,34 +507,27 @@ char   *vec[];
     rcend ();
 }
 
-#ifdef BPOP
-/* ARGSUSED */
 
-static int  xtnd1 (s)
-char   *s;
+#ifdef BPOP
+
+static int
+xtnd1 (char *s)
 {
     return OK;
 }
 #endif	BPOP
 
 
-bbread (bb, vecp, vec)
-register struct bboard  *bb;
-int	vecp;
-char   *vec[];
+void
+bbread (struct bboard *bb, int vecp, char **vec)
 {
-    int     child_id,
-            pd[2];
-    char    buf1[BUFSIZ],
-            buf2[BUFSIZ],
-            buf3[BUFSIZ];
-#ifdef	BPOP
-    int	    nmsgs,
-	    nbytes;
-    char    buf4[BUFSIZ],
-            buf5[BUFSIZ];
-#endif	BPOP
+    int child_id, pd[2];
+    char buf1[BUFSIZ], buf2[BUFSIZ], buf3[BUFSIZ];
     struct stat st;
+#ifdef	BPOP
+    int	nmsgs, nbytes;
+    char buf4[BUFSIZ], buf5[BUFSIZ];
+#endif	BPOP
 
 #ifdef	BPOP
     if (bb->bb_flags & BB_REMOTE) {
@@ -613,17 +605,17 @@ char   *vec[];
 }
 
 
-pgmread (pd, child_id, bb)
-int     pd,
-        child_id;
-register struct bboard  *bb;
+void
+pgmread (int pd, int child_id, struct bboard *bb)
 {
     int i, j, n;
     SIGNAL_HANDLER estat, hstat, istat, qstat, tstat;
-    char    buffer[BUFSIZ];
+    char buffer[BUFSIZ];
     struct bbcount *selected;
 
+#ifdef SIGEMT
     estat = SIGNAL (SIGEMT, sigser);
+#endif
     hstat = SIGNAL (SIGHUP, hupser);
     istat = SIGNAL (SIGINT, SIG_IGN);
     qstat = SIGNAL (SIGQUIT, SIG_IGN);
@@ -634,7 +626,9 @@ register struct bboard  *bb;
     close (pd);
     pidXwait (child_id, mshproc);
 
+#ifdef SIGEMT
     SIGNAL (SIGEMT, estat);
+#endif
     SIGNAL (SIGHUP, hstat);
     SIGNAL (SIGINT, istat);
     SIGNAL (SIGQUIT, qstat);
@@ -692,14 +686,13 @@ hupser (int i)
 }
 
 
-rcinit (rc)
-register char  *rc;
+void
+rcinit (char *rc)
 {
-    int     state;
-    register char  *cp;
-    char    key[NAMESZ],
-            value[BUFSIZ];
-    register FILE  *bbrc;
+    int state;
+    register char *cp;
+    char key[NAMESZ], value[BUFSIZ];
+    register FILE *bbrc;
 
     if ((cp = rc ? rc : getenv ("MHBBRC")) && *cp) {
 	rcfile = path (cp, TFILE);
@@ -740,6 +733,7 @@ register char  *rc;
 }
 
 
+void
 rcend (void)
 {
     SIGNAL_HANDLER hstat, istat, qstat, tstat;
@@ -771,9 +765,8 @@ rcend (void)
 }
 
 
-rcput (bbrc, p)
-register FILE *bbrc;
-register struct bbcount *p;
+void
+rcput (FILE *bbrc, struct bbcount *p)
 {
     if (p == NULL)
 	return;
@@ -785,8 +778,8 @@ register struct bbcount *p;
 
 
 #ifdef	SIGTSTP
-static RETSIGTYPE tstpser (sig)
-int	sig;
+static RETSIGTYPE
+tstpser (int sig)
 {
     pid_t pid;
 #ifdef WAITINT
@@ -822,9 +815,8 @@ int	sig;
 #endif /* SIGTSTP */
 
 
-static	void	bbreset (bb, i)
-register struct bboard  *bb;
-int i;
+static void
+bbreset (struct bboard *bb, int i)
 {
     struct bbcount *selected;
 
@@ -837,12 +829,10 @@ int i;
     changed++;
 }
 
-struct bbcount *add_count (p, w, i)
-register struct bbcount *p;
-register char   *w;
-int     i;
+struct bbcount *
+add_count (struct bbcount *p, char *w, int i)
 {
-    int     cond;
+    int cond;
 
     if (p == NULL) {
 	p = (struct bbcount *) malloc (sizeof *p);
@@ -863,11 +853,10 @@ int     i;
 }
 
 
-struct bbcount *seek_count (p, w)
-register struct bbcount *p;
-register char   *w;
+struct bbcount *
+seek_count (struct bbcount *p, char *w)
 {
-    int     cond;
+    int cond;
 
     if (p == NULL || (cond = strcmp (w, p->key)) == 0)
 	return p;
@@ -906,8 +895,7 @@ default_bboards () {
 	if (oops)
 	    advise (NULL, "please fix the %s: entry in your %s file",
 		"bboards", mh_profile);
-    }
-    else {
+    } else {
 #ifdef	UCL
 	bbs[bbp++] = "system";
 	bbs[bbp] = NULL;
@@ -931,9 +919,8 @@ default_bboards () {
 }
 
 
-add_bb (s, hush)
-register char   *s;
-int     hush;
+void
+add_bb (char *s, int hush)
 {
     register struct bboard  *bb;
     static struct bboard   *tail = NULL;
@@ -962,21 +949,21 @@ int     hush;
 }
 
 
-#ifdef	BPOP
-static struct bboard   *Bhead = NULL;
-static struct bboard   *Btail = NULL;
+#ifdef BPOP
+static struct bboard *Bhead = NULL;
+static struct bboard *Btail = NULL;
 
-static int xtnd2 (s)
-char   *s;
+static int
+xtnd2 (char *s)
 {
-    int     maxima;
-    char    name[BUFSIZ];
+    int maxima;
+    char name[BUFSIZ];
     register struct bboard *bb;
 
     if (sscanf (s, "%s %d", name, &maxima) != 2)
 	adios (NULL, "XTND2 botch: %s", s);
 
-    if ((bb = (struct bboard   *) calloc (1, sizeof *bb)) == NULL)
+    if ((bb = (struct bboard   *) calloc (1, sizeof(*bb))) == NULL)
 	adios (NULL, "insufficient memory");
     bb->bb_name = getcpy (name);
 #ifdef	NNTP
@@ -1024,8 +1011,8 @@ char   *s;
 }
 
 
-static int xtnd3 (s)
-char   *s;
+static int
+xtnd3 (char *s)
 {
     static int  bbs_int = 0;
     static struct bboard   *bb;
@@ -1095,17 +1082,15 @@ char   *s;
 }
 
 
-static char **getip (s)
-char   *s;
+static char **
+getip (char *s)
 {
-    register char **ap,
-                  **p,
-                  **q;
+    register char **ap, **p, **q;
 
     for (p = ap = brkstring (getcpy (s), " ", "\n"); *p; p++)
 	continue;
 
-    q = (char **) calloc ((unsigned) (p - ap + 1), sizeof *q);
+    q = (char **) calloc ((size_t) (p - ap + 1), sizeof *q);
     if (q == NULL)
 	adios (NULL, "insufficient memory");
 
@@ -1117,12 +1102,13 @@ char   *s;
 }
 
 
-static struct bboard   *rover = NULL;
+static struct bboard *rover = NULL;
 
-struct bboard  *getbbpop () {
-    int     snoop;
-    char   *cp,
-           *pass = NULL;
+struct bboard *
+getbbpop (void)
+{
+    int snoop;
+    char *cp, *pass = NULL;
     register struct bboard *bb;
 
     if (didpop != NOTOK && ((bb = getbbent ()) || !host))
@@ -1165,17 +1151,17 @@ struct bboard  *getbbpop () {
 #endif BPOP
 
 
-struct bboard *getbbaux (s)
-register char	*s;
+struct bboard *
+getbbaux (char *s)
 {
 #ifdef	BPOP
-    int	    nlatch = host ? 1 : 0;
+    int	nlatch = host ? 1 : 0;
 #endif	BPOP
     register char  **ap;
     register struct bbcount *selected;
     register struct bboard *bb;
-    static struct bboard   *head = NULL,
-                           *tail = NULL;
+    static struct bboard *head = NULL,
+                         *tail = NULL;
 
     for (bb = head; bb; bb = bb->bb_next) {
 	if (strcmp (bb->bb_name, s) == 0)
