@@ -252,9 +252,10 @@ try_it_again: ;
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse the message range/sequence/name and set SELECTED */
     if (!m_convert (mp, msg))
 	done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
     if (mp->numsel > 1)
 	adios (NULL, "only one message at a time!");
@@ -265,11 +266,11 @@ go_to_it: ;
 	adios (msgnam, "unable to open message");
 
     if (!file) {
-	m_replace (pfolder, folder);
+	m_replace (pfolder, folder);	/* update current folder   */
 	if (mp->lowsel != mp->curmsg)
 	    m_setcur (mp, mp->lowsel);
 	m_sync (mp);
-	m_update ();
+	m_update ();			/* update the context file */
     }
 
     if (nwhat)
