@@ -1,6 +1,8 @@
 
 /*
- * folder(s).c -- set/list the current folder/message
+ * folder(s).c -- set/list the current message and/or folder
+ *             -- push/pop a folder onto/from the folder stack
+ *             -- list the folder stack
  *
  * $Id$
  */
@@ -60,17 +62,18 @@ static struct swit switches[] = {
 
 extern int errno;
 
-static int fshort = 0;
-static int fcreat = 0;
-static int fpack = 0;
-static int fverb = 0;
-static int fheader = 0;
-static int frecurse = 0;
-static int ftotonly = 0;
-static int msgtot = 0;
-static int foldtot = 0;
-static int start = 0;
-static int foldp = 0;
+static int fshort   = 0;	/* output only folder names                 */
+static int fcreat   = 0;	/* should we ask to create new folders?     */
+static int fpack    = 0;	/* are we packing the folder?               */
+static int fverb    = 0;	/* print actions taken while packing folder */
+static int fheader  = 0;	/* should we output a header?               */
+static int frecurse = 0;	/* recurse through subfolders               */
+static int ftotonly = 0;	/* should we only output the totals?        */
+static int msgtot   = 0;	/* total number of messages                 */
+static int foldtot  = 0;	/* total number of folders                  */
+
+static int start    = 0;
+static int foldp    = 0;
 
 static char *mhdir;
 static char *stack = "Folder-Stack";
@@ -78,17 +81,17 @@ static char folder[BUFSIZ];
 static char *folds[NFOLDERS + 1];
 
 /*
- * prototypes
+ * static prototypes
  */
 static void dodir (char *);
 static int pfold (char *, char *);
+static void print_totals (void);
 static int sfold (struct msgs *, char *);
 static void addir (char *);
 static void addfold (char *);
 static int compare (char *, char *);
-static void dother (void);
-
-struct msgs *tfold (struct msgs *);
+static void doreadonly (void);
+static struct msgs *tfold (struct msgs *);
 
 
 main (int argc, char **argv)
@@ -228,8 +231,14 @@ main (int argc, char **argv)
 	free (path ("./", TFOLDER));
     mhdir = concat (m_maildir (""), "/", NULL);
 
+    /*
+     * If we aren't working with the folder stack
+     * (-push, -pop, -list) then the default is to print.
+     */
     if (pushsw == 0 && popsw == 0 && listsw == 0)
 	printsw++;
+
+    /* Pushing a folder onto the folder stack */
     if (pushsw) {
 	if (!argfolder) {
 	    /* If no folder is given, the current folder and */
@@ -244,14 +253,17 @@ main (int argc, char **argv)
 	    for (cp = getcpy (m_getfolder ()); *ap; ap++)
 		cp = add (*ap, add (" ", cp));
 	    free (dp);
-	    m_replace (stack, cp);
-	}
-	else
+	    m_replace (stack, cp);	/* update folder stack */
+	} else {
+	    /* update folder stack */
 	    m_replace (stack,
 		    (cp = m_find (stack))
 		    ? concat (m_getfolder (), " ", cp, NULL)
 		    : getcpy (m_getfolder ()));
+	}
     }
+
+    /* Popping a folder off of the folder stack */
     if (popsw) {
 	if (argfolder)
 	    adios (NULL, "sorry, no folders allowed with -pop");
@@ -267,10 +279,9 @@ main (int argc, char **argv)
 	    cp = getcpy (*ap++);
 	    for (; *ap; ap++)
 		cp = add (*ap, add (" ", cp));
-	    m_replace (stack, cp);
+	    m_replace (stack, cp);		/* update folder stack */
 	} else {
-	    /* else just delete that entry */
-	    m_delete (stack);
+	    m_delete (stack);	/* delete folder stack entry from context */
 	}
 	free (dp);
     }
@@ -278,10 +289,12 @@ main (int argc, char **argv)
 	cp = m_maildir(argfolder);
 	if (access (cp, F_OK) == NOTOK)
 	    adios (cp, "unable to find folder");
-	m_replace (pfolder, argfolder);
-	m_update ();
+	m_replace (pfolder, argfolder);	/* update current folder   */
+	m_update ();			/* update the context file */
 	argfolder = NULL;
     }
+
+    /* Listing the folder stack */
     if (listsw) {
 	printf ("%s", argfolder ? argfolder : m_getfolder ());
 	if ((cp = m_find (stack))) {
@@ -296,35 +309,28 @@ main (int argc, char **argv)
 	    done (0);
     }
 
+    /* Do all top level folders */
     if (all) {
 	fheader = 0;
 	if (argfolder) {
 	    strcpy (folder, argfolder);
 	    if (pfold (argfolder, msg)) {
-		m_replace (pfolder, argfolder);
-		m_update ();
+		m_replace (pfolder, argfolder);	/* update current folder   */
+		m_update ();			/* update the context file */
 	    }
 	    if (!frecurse)	/* recurse not done in pfold(), */
 		dodir (folder);	/* so just list all level-1 sub-folders */
-	}
-	else {
+	} else {
 	    if (msg)
 		admonish (NULL, "no folder given for message %s", msg);
-	    dother ();
-
+	    doreadonly ();
 	    strcpy (folder, (cp = m_find (pfolder)) ? cp : "");
 	    dodir (".");
 	}
 
-	if (!fshort) {
-	    if (!ftotonly)
-		printf ("\n\t\t     ");
-	    printf ("TOTAL= %*d message%c in %d folder%s.\n",
-		    DMAXFOLDER, msgtot, msgtot != 1 ? 's' : ' ',
-		    foldtot, foldtot != 1 ? "s" : "");
-	}
-    }
-    else {
+	if (!fshort)
+	    print_totals();	/* print folder/message totals */
+    } else {
 	fheader++;
 
 	strcpy (folder, argfolder ? argfolder : m_getfolder ());
@@ -347,10 +353,10 @@ main (int argc, char **argv)
 	}
 
 	if (pfold (folder, msg) && argfolder)
-	    m_replace (pfolder, argfolder);
+	    m_replace (pfolder, argfolder);	/* update current folder */
     }
 
-    m_update ();
+    m_update ();	/* update the context file */
     done (0);
 }
 
@@ -381,7 +387,7 @@ pfold (char *fold, char *msg)
 {
     int	hack, others, retval = 1;
     register char *mailfile;
-    register struct msgs   *mp = NULL;
+    register struct msgs *mp = NULL;
 
     mailfile = m_maildir (fold);
     if (chdir (mailfile) == NOTOK) {
@@ -403,6 +409,7 @@ pfold (char *fold, char *msg)
 	}
     }
 
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (fold))) {
 	admonish (NULL, "unable to read folder %s", fold);
 	return 0;
@@ -415,12 +422,14 @@ pfold (char *fold, char *msg)
 
     if (fshort)
 	goto out;
+
     foldtot++;
     msgtot += mp->nummsg;
 
     if (ftotonly)
 	goto out;
 
+    /* print header */
     if (!fheader++)
 	printf ("\t\tFolder  %*s# of messages (%*srange%*s); cur%*smsg  (other files)\n",
 	    DMAXFOLDER, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "",
@@ -446,7 +455,7 @@ pfold (char *fold, char *msg)
 
 out: ;
     others = mp->msgflags & OTHERS;
-    m_fmsg (mp);
+    m_fmsg (mp);			/* free folder/message info */
 
     if (frecurse && others)
 	dodir (fold);
@@ -454,9 +463,25 @@ out: ;
     return retval;
 }
 
+
+/*
+ * print folder/message totals
+ */
+static void
+print_totals (void)
+{
+    if (!ftotonly)
+	printf ("\n\t\t     ");
+    printf ("TOTAL= %*d message%c in %d folder%s.\n",
+	DMAXFOLDER, msgtot, msgtot != 1 ? 's' : ' ',
+	foldtot, foldtot != 1 ? "s" : "");
+}
+
+
 static int
 sfold (struct msgs *mp, char *msg)
 {
+    /* parse the message range/sequence/name and set SELECTED */
     if (!m_convert (mp, msg))
 	return 0;
 
@@ -464,16 +489,16 @@ sfold (struct msgs *mp, char *msg)
 	admonish (NULL, "only one message at a time!");
 	return 0;
     }
-    m_setseq (mp);
+    m_setseq (mp);		/* set the previous-sequence */
     m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_update ();
+    m_update ();		/* update the context file */
 
     return 1;
 }
 
 
-struct msgs *
+static struct msgs *
 tfold (struct msgs *mp)
 {
     register int hole, msgnum;
@@ -482,7 +507,7 @@ tfold (struct msgs *mp)
     if (mp->lowmsg > 1 && (mp = m_remsg (mp, 1, mp->hghmsg)) == NULL)
 	adios (NULL, "unable to allocate folder storage");
 
-    for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++)
+    for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++) {
 	if (mp->msgstats[msgnum] & EXISTS) {
 	    if (msgnum != hole) {
 		strcpy (newmsg, m_name (hole));
@@ -502,12 +527,13 @@ tfold (struct msgs *mp)
 	    }
 	    hole++;
 	}
+    }
     if (mp->nummsg > 0) {
 	mp->lowmsg = 1;
 	mp->hghmsg = hole - 1;
     }
     m_sync (mp);
-    m_update ();
+    m_update ();	/* update the context file */
 
     return mp;
 }
@@ -581,8 +607,12 @@ compare (char *s1, char *s2)
     return 0;
 }
 
+/*
+ * Do the read only folders
+ */
+
 static void
-dother (void)
+doreadonly (void)
 {
     int	atrlen;
     char atrcur[BUFSIZ];
