@@ -1,6 +1,6 @@
 
 /*
- * forw.c -- forward messages
+ * forw.c -- forward message(s)
  *
  * $Id$
  */
@@ -350,10 +350,11 @@ try_it_again: ;
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous sequence */
 
 go_to_it: ;
     if (filter && access (filter, R_OK) == NOTOK)
@@ -417,11 +418,11 @@ go_to_it: ;
 	m_replace (buf, getcpy (value));
     }
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder   */
     if (mp->lowsel != mp->curmsg)
 	m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_update ();
+    m_update ();			/* update the context file */
 
 edit_it: ;
     if (nwhat)
@@ -475,7 +476,7 @@ mhl_draft  (int out, char *digest, int volume, int issue,
 		adios (NULL, "more than %d messages for %s exec",
 			vec[0], MAXARGS - i);
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    vec[i++] = getcpy (m_name (msgnum));
 	    vec[i] = NULL;
 
@@ -507,7 +508,7 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 		 mp->numsel == 1 ? "" : "s", mp->foldpath);
 	write (out, buffer, strlen (buffer));
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	    if (is_selected (mp, msgnum)) {
 		sprintf (buffer, " %s", m_name (msgnum));
 		write (out, buffer, strlen (buffer));
 	    }
@@ -518,8 +519,8 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 #endif /* MIME */
 
     msgcnt = 1;
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
+	if (is_selected (mp, msgnum)) {
 	    if (digest)
 		strcpy (buffer, msgnum == mp->lowsel ? delim3 : delim4);
 	    else {
@@ -542,6 +543,7 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 
 	    msgcnt++;
 	}
+    }
 
     if (digest)
 	strcpy (buffer, delim4);
