@@ -18,7 +18,7 @@ static struct swit switches[] = {
 
 main(int argc, char **argv)
 {
-    int msgp = 0, msgnum;
+    int msgp = 0, i;
     char *cp, *maildir, *folder = NULL, buf[100];
     char **ap, **argp, *arguments[MAXARGS], *msgs[MAXARGS];
     struct msgs *mp;
@@ -69,6 +69,8 @@ main(int argc, char **argv)
     if (!folder)
 	folder = m_getfolder ();
     maildir = m_maildir (folder);
+
+    /* If no messages are given, print folder pathname */
     if (!msgp) {
 	printf ("%s\n", maildir);
 	done (0);
@@ -76,26 +78,32 @@ main(int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
 	adios (NULL, "unable to allocate folder storage");
+
     mp->msgflags |= MHPATH;
 
-    for (msgnum = 0; msgnum < msgp; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    /* parse all the message ranges/sequences and set SELECTED */
+    for (i = 0; i < msgp; i++)
+	if (!m_convert (mp, msgs[i]))
 	    done (1);
-    m_setseq (mp);
+
+    m_setseq (mp);	/* set the previous-sequence */
 
     if (mp->numsel > MAXARGS - 2)
 	adios (NULL, "more than %d messages", MAXARGS - 2);
 
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
-	    printf ("%s/%s\n", mp->foldpath, m_name (msgnum));
+    for (i = mp->lowsel; i <= mp->hghsel; i++)
+	if (is_selected (mp, i))
+	    printf ("%s/%s\n", mp->foldpath, m_name (i));
 
     m_sync (mp);
-    m_update ();
+    m_fmsg (mp);	/* free folder/message structure */
+    m_update ();	/* update the context file       */
     done (0);
 }
