@@ -95,11 +95,10 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp)
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
     if ((nxtbuf = compbuffers = (char **)
-	    calloc((unsigned)ncomps,sizeof(char *))) 
-	    == (char **)NULL)
+	    calloc((size_t) ncomps, sizeof(char *))) == (char **)NULL)
 	adios (NULL, "unable to allocate component buffers");
     if ((savecomp = used_buf = (struct comp **)
-	    calloc((unsigned)(ncomps+1),sizeof(struct comp *)))
+	    calloc((size_t) (ncomps+1), sizeof(struct comp *)))
 	    == (struct comp **)NULL)
 	adios (NULL, "unable to allocate component buffer stack");
     savecomp += ncomps + 1;
