@@ -326,24 +326,29 @@ main (int argc, char **argv)
 
 	if (chdir (maildir) == NOTOK)
 	    adios (maildir, "unable to change directory to");
+
+	/* read folder and create message structure */
 	if (!(mp = m_gmsg (dfolder)))
 	    adios (NULL, "unable to read folder %s", dfolder);
+
 	if (mp->hghmsg == 0)
 	    adios (NULL, "no messages in %s", dfolder);
 
+	/* parse all the message ranges/sequences and set SELECTED */
 	for (msgnum = 0; msgnum < msgp; msgnum++)
 	    if (!m_convert (mp, msgs[msgnum]))
 		done (1);
-	m_setseq (mp);
+	m_setseq (mp);	/* set the previous-sequence */
 
-	for (msgp = 0, msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	for (msgp = 0, msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
+	    if (is_selected (mp, msgnum)) {
 		msgs[msgp++] = getcpy (m_name (msgnum));
 #ifdef notdef
 		mp->msgstats[msgnum] |= DELETED;
 #endif /* notdef */
 		mp->msgstats[msgnum] &= ~EXISTS;
 	    }
+	}
 	mp->msgflags |= SEQMOD;
 
 	m_sync (mp);
@@ -442,7 +447,7 @@ go_to_it: ;
 		break;
 	}
 
-    m_update ();
+    m_update ();	/* update the context file */
 
     done (status);
 }
