@@ -156,12 +156,12 @@ main (int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    if (mode != SHOW)
 		goto usage;
 	    else
 		msgs[msgp++] = cp;
+	}
     }
     procp = vecp;
 
@@ -193,31 +193,37 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
+
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
-	    mp->msgstats[msgnum] |= UNSEEN;
+	if (is_selected(mp, msgnum))
+	    set_unseen (mp, msgnum);
     m_setseq (mp);
     m_setvis (mp, 1);
 
     if (mp->numsel > MAXARGS - 2)
 	adios (NULL, "more than %d messages for show exec", MAXARGS - 2);
+
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected(mp, msgnum))
 	    vec[vecp++] = getcpy (m_name (msgnum));
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder   */
     if (mp->hghsel != mp->curmsg)
 	m_setcur (mp, mp->hghsel);
-    m_sync (mp);
-    m_update ();
+    m_sync (mp);			/* synchronize sequences   */
+    m_update ();			/* update the context file */
 
     if (vecp == 2 && headersw)
 	printf ("(Message %s:%s)\n", folder, vec[1]);
@@ -229,9 +235,6 @@ go_to_it: ;
 
 #ifdef MIME
     if (!nshow && !getenv ("NOMHNPROC")) {
-	if (!(cp = m_find ("mhnproc")))
-	    cp = "mhn";
-
 	if (draftsw || file) {
 	    if (nontext (vec[vecp - 1])) {
 		vec[vecp] = vec[vecp - 1];
@@ -239,21 +242,21 @@ go_to_it: ;
 		vecp++;
 		goto use_mmp;
 	    }
-	}
-	else
+	} else {
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if ((mp->msgstats[msgnum] & SELECTED)
-		        && nontext (m_name (msgnum))) {
+		if (is_selected(mp, msgnum) && nontext (m_name (msgnum))) {
 use_mmp: ;
-		    proc = cp;
+		    proc = mhnproc;
 		    vec[vecp++] = "-show";
 		    vec[vecp] = NULL;
 		    goto finish;
 		}
+	}
     }
 #endif /* MIME */
+
     if (nshow)
-	proc = "/bin/cat";
+	proc = catproc;
     else {
 	if (folder && !draftsw && !file)
 	    m_putenv ("mhfolder", folder);
@@ -320,8 +323,8 @@ nontext (char *msgnam)
 	    case FLDPLUS:
 	    case FLDEOF:
 	        if (uleq (name, TYPE_FIELD)) {
-		    int	    passno;
-		    char     c;
+		    int	passno;
+		    char c;
 
 		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
