@@ -25,15 +25,16 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	m_putenv ("mhfolder", mp->foldpath);
     else
 	unputenv ("mhfolder");
-    if (altmsg)
+    if (altmsg) {
 	if (mp == NULL || *altmsg == '/' || cwd == NULL)
 	    m_putenv ("mhaltmsg", altmsg);
 	else {
 	    sprintf (buffer, "%s/%s", mp->foldpath, altmsg);
 	    m_putenv ("mhaltmsg", buffer);
 	}
-    else
+    } else {
 	unputenv ("mhaltmsg");
+    }
     if ((bp = getenv ("mhaltmsg")))/* XXX */
 	m_putenv ("editalt", bp);
     sprintf (buffer, "%d", dist);
@@ -52,12 +53,10 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	found = 0;
 	bp = buffer;
 	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	    if (is_selected(mp, msgnum)) {
 		sprintf (bp, "%s%s", found ? " " : "", m_name (msgnum));
 		bp += strlen (bp);
-		for (k = msgnum + 1;
-			k <= mp->hghmsg && mp->msgstats[k] & SELECTED;
-			k++)
+		for (k = msgnum + 1; k <= mp->hghmsg && is_selected(mp, k); k++)
 		    continue;
 		if (--k > msgnum) {
 		    sprintf (bp, "-%s", m_name (k));
@@ -74,7 +73,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	}
     }
 
-    m_update ();
+    m_update ();	/* update the context file */
     fflush (stdout);
 
     if (cwd)
